@@ -130,6 +130,7 @@ type term =
 type atom =
   | Ain of term * Constant.t option * Constant.t option
   | Arel of term * term * Constant.t * Constant.t
+  | Alin of term * term * Constant.t * Constant.t
   | Aeq of term * term
 
 type pred =
@@ -195,6 +196,7 @@ let coq_rtImpl = coq_ref_Gappa_Private "rtImpl"
 let coq_RAtom = coq_ref_Gappa_Private "RAtom"
 let coq_raBound = coq_ref_Gappa_Private "raBound"
 let coq_raRel = coq_ref_Gappa_Private "raRel"
+let coq_raLin = coq_ref_Gappa_Private "raLin"
 let coq_raEq = coq_ref_Gappa_Private "raEq"
 let coq_raLe = coq_ref_Gappa_Private "raLe"
 let coq_raGeneric = coq_ref_Gappa_Private "raGeneric"
@@ -630,6 +632,8 @@ let tr_atom uv t =
         Ain (tr_term uv e, l, u)
     | c, [er;ex;l;u] when is_global coq_raRel c ->
         Arel (tr_term uv er, tr_term uv ex, tr_const l, tr_const u)
+    | c, [er;ex;l;u] when is_global coq_raLin c ->
+        Alin (tr_term uv er, tr_term uv ex, tr_const l, tr_const u)
     | c, [er;ex] when is_global coq_raEq c ->
         Aeq (tr_term uv er, tr_term uv ex)
     | _ ->
@@ -726,6 +730,9 @@ let print_atom fmt = function
   | Arel (t1, t2, c1, c2) ->
       fprintf fmt "%a -/ %a in [%a,%a]"
         print_term t1 print_term t2 Constant.print c1 Constant.print c2
+  | Alin (t1, t2, c1, c2) ->
+      fprintf fmt "%a // %a in [%a,%a]"
+        print_term t1 print_term t2 Constant.print c1 Constant.print c2
   | Aeq (t1, t2) ->
       fprintf fmt "%a = %a" print_term t1 print_term t2
 
